# 20220531_dec3476_std

Standard production for declination 3476 that was missing Proton simtel files for some nodes.

Config generated with:

```
lstmcpipe_generate_config  PathConfigAllSkyFull --prod_id 20220531_dec3476_std --dec_list dec_3476
``` 

